import axios from 'axios';
import dotenv from 'dotenv';

dotenv.config();

const API_URL = process.env.API_URL;
const INSTANCE_NAME = process.env.INSTANCE_NAME;
const API_KEY = process.env.API_KEY;

if (!API_URL || !INSTANCE_NAME || !API_KEY) {
  throw new Error('Required environment variables are not defined.');
}

// Send a message
export async function sendMessage(phone: string, message: string) {
  try {
    await axios.post(`${API_URL}/message/sendText/${INSTANCE_NAME}`, {
      number: phone,
      text: message,
    }, {
      headers: {
        'Content-Type': 'application/json',
        apikey: API_KEY,
      },
    });
  } catch (error) {
    console.error('Error sending message:', error);
  }
}
